@@ -1,6 +1,6 @@
 package Net::OpenSSH::OSTracer;
 
-our $VERSION = '0.58_01';
+our $VERSION = '0.65_06';
 
 use strict;
 use warnings;
@@ -116,9 +116,9 @@ Net::OpenSSH::OSTracer - trace ssh master process at the OS level
 =head1 DESCRIPTION
 
 This is a Net::OpenSSH helper module that allows you to trace the
-master ssh process at the operating system level using the proper
-utility available in your system (i.e, strace, truss, ktruss, tusc,
-etc.).
+master C<ssh> process at the operating system level using the proper
+utility available in your system (e.g., C<strace>, C<truss>,
+C<ktruss>, C<tusc>, etc.).
 
 This feature can be used when debugging your programs or to report
 bugs on the module.
@@ -127,7 +127,7 @@ It is enabled setting the flag 512 on the C<$Net::OpenSSH::debug> variable:
 
   $Net::OpenSSH::debug |= 512;
 
-By default the ouput files of the tracer are saved as
+By default the output files of the tracer are saved as
 C</tmp/net_openssh_master.$pid.$tracer_type>.
 
 Also, the output send by the tracer to stdout/stderr is saved as
@@ -140,28 +140,28 @@ The module can be configured through the following global variables:
 =item $Net::OpenSSH::OSTracer::type
 
 By default, the module decides which tracer to use in base to the
-operative system name. This variable allows to select a different
+operating system name. This variable allows one to select a different
 tracer.
 
-Currently accepted types are: strace (linux), ktrace (*bsd), tusc
-(hp-ux) and truss (solaris and aix).
+Currently accepted types are: C<strace> (Linux), C<ktrace> (*BSD),
+C<tusc> (HP-UX) and C<truss> (Solaris and AIX).
 
 =item $Net::OpenSSH::OSTracer::cmd
 
-Command to execute for tracing the ssh process.
+Command to execute for tracing the C<ssh> process.
 
-By default, it inferres it from the tracer type selected.
+By default, it infers it from the tracer type selected.
 
 =item $Net::OpenSSH::OSTracer::output
 
-Basename for the destination file. The PID of the ssh process and the
-tracer type will be appended.
+Basename for the destination file. The PID of the C<ssh> process and
+the tracer type will be appended.
 
 =item $Net::OpenSSH::OSTracer::sudo
 
 This variable can be used to request the tracer to be run with C<sudo>
-(some operating systems as for example Ubuntu, do not allow to attach
-tracers, even to your own processes, unless you do it as root).
+(some operating systems as for example Ubuntu, do not allow one to
+attach tracers, even to your own processes, unless you do it as root).
 
 The variable has to be set with the path of the C<sudo> binary. For
 instance:
@@ -175,7 +175,7 @@ variable C<SUDO_ASKPASS>. For instance:
 
 =item $Net::OpenSSH::OSTracer::delay
 
-This variable can be used to delay the ssh execution so that the
+This variable can be used to delay the C<ssh> execution so that the
 tracer can attach the process first. This is specially handy when
 using C<sudo> with a password.
 
